<?php
/**
 * @file
 * Gardengnome player field formatter.
 */

/**
 * Implements hook_field_formatter_info().
 *
 * Provide a formatter for gardengnome packages.
 */
function gardengnome_player_field_formatter_info() {
  $formatters = array();
  $formatters['gardengnome_package'] = array(
    'label' => t('Gardengnome Package'),
    'field types' => array('gardengnome_package'),
    'settings' => array(
      'preview_style' => 'none',
      'display_style' => 'inline',
      'autoplay' => 'inline',
      'popup_height' => 'inline',
      'popup_width' => 'inline',
    ),
  );
  return $formatters;
}

/**
 * Implements hook_field_formatter_view().
 */
function gardengnome_player_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {
  $element = array();
  $settings = $display['settings'];

  foreach ($items as $delta => $item) {
    $element[$delta] = array(
      '#markup' => theme('gardengnome_player', array(
        'package' => $item['uri'],
        'preview_style' => $settings['preview_style'],
        'display_style' => ($settings['display_style']),
        'autoplay' => ($settings['autoplay']),
        'popup_width' => ($settings['popup_width']),
        'popup_height' => ($settings['popup_height']),
      )),
    );
    continue;

    $directory = parse_url(file_create_url(_gardengnome_player_extract($item['uri'])));
    $directory = substr($directory['path'], 1);
    if ($settings['preview_style'] == 'none') {
      $preview = theme('image', array(
        'path' => $directory . '/preview.jpg',
      ));
    }
    else {
      $preview = theme('image_style', array(
        'style_name' => $settings['preview_style'],
        'path' => $directory . '/preview.jpg',
      ));
    }

    $data = _gardengnome_player_package_info($directory);

    drupal_add_js(drupal_get_path('module', 'gardengnome_player') . '/gardengnome_player.js');

    if ($data['swfobject']) {
      drupal_add_js($data['swfobject']);
    }

    if ($data['html5']) {
      drupal_add_js($data['html5']);
    }

    if ($data['skin']) {
      drupal_add_js($data['skin']);
    }

    $data['display'] = $settings['display_style'];

    $attributes = array(
      'data-popup-width' => isset($settings['popup_width']) ? $settings['popup_width'] : 400,
      'data-popup-height' => isset($settings['popup_height']) ? $settings['popup_height'] : 300,
    );

    foreach ($data as $key => $value) {
      if ($data[$key]) {
        $attributes['data-' . $key] = $value;
      }
    }
    $attributes = array();

    drupal_attributes($attributes);
    $preview = l($preview, $directory, array(
      'html' => TRUE,
      'attributes' => $attributes,
    ));

    $element[$delta] = array(
      '#markup' => '<div class="gardengnome-player">' . $preview . '</div>',
    );
  }
  return $element;
}

/**
 * Implements hook_field_formatter_settings_form().
 */
function gardengnome_player_field_formatter_settings_form($field, $instance, $view_mode, $form, &$form_state) {
  $settings = $instance['display'][$view_mode]['settings'];

  $element = array();
  $element['preview_style'] = array(
    '#type' => 'select',
    '#title' => t('Preview image style'),
    '#description' => t('Choose an image style for the preview image. Inline displays will inherit it\'s size.'),
    '#options' => array(
      'none' => t('None (original image)'),
    ),
    '#default_value' => isset($settings['preview_style']) ? $settings['preview_style'] : 'none',
  );

  foreach (image_styles() as $key => $style) {
    $element['preview_style']['#options'][$key] = $style['label'];
  }

  $element['display_style'] = array(
    '#type' => 'select',
    '#title' => t('Display style'),
    '#description' => t('Choose a display style. <em>Inline</em> will inherit the preview images size. </em><strong>Do not use <em>Inline autoplay</em> if many items are displayed on one page!</strong>'),
    '#options' => array(
      'popup' => t('Popup'),
      'inline' => t('Inline'),
    ),
    '#default_value' => isset($settings['display_style']) ? $settings['display_style'] : 'blank',
  );

  $element['autoplay'] = array(
    '#type' => 'checkbox',
    '#title' => t('Autoplay'),
    '#description' => t('Start the player on page load. Popup displays always start immediatly.'),
    '#default_value' => isset($settings['autoplay']) ? $settings['autoplay'] : FALSE,
  );

  return $element;
}

/**
 * Implements hook_field_formatter_settings_summary().
 */
function gardengnome_player_field_formatter_settings_summary($field, $instance, $view_mode) {
  $settings = $instance['display'][$view_mode]['settings'];
  $styles = array('none' => 'original');
  if (module_exists('image')) {
    foreach (image_styles() as $key => $style) {
      $styles[$key] = $style['name'];
    }
  }
  $displays = array(
    'popup' => t('in a popup window'),
    'inline' => t('inline'),
  );
  $summary = t('Preview as %style image and play %display.', array(
    '%style' => $styles[$settings['preview_style']],
    '%display' => $displays[$settings['display_style']],
  ));
  return $summary;
}
